==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/include/registerform.php <==
<?php
// $Id: registerform.php,v 1.10 2005/09/20 05:47:57 aga4096 Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include_once XOOPS_ROOT_PATH."/class/xoopslists.php";
include_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";

// initialize form vars
$uname = isset($_POST['uname']) ? $myts->makeTboxData4PreviewInForm($_POST['uname']) : "";
$realname = isset($_POST['realname']) ? $myts->makeTboxData4PreviewInForm($_POST['realname']) : "";
$email = isset($_POST['email']) ? $myts->makeTboxData4PreviewInForm($_POST['email']) : "";
$user_viewemail = isset($_POST['user_viewemail']) ? $_POST['user_viewemail'] : "";
$url = isset($_POST['url']) ? $myts->makeTboxData4PreviewInForm($_POST['url']) : "";
$timezone_offset = isset($_POST['timezone_offset']) ? $_POST['timezone_offset'] : "";
//$user_avatar = isset($_POST['user_avatar']) ? $_POST['user_avatar'] : "blank.gif";
// initialize form vars for platform user
$address = isset($_POST['address']) ? $myts->makeTboxData4PreviewInForm($_POST['address']) : "";
$division = isset($_POST['division']) ? $myts->makeTboxData4PreviewInForm($_POST['division']) : "";
$company_name = isset($_POST['company_name']) ? $myts->makeTboxData4PreviewInForm($_POST['company_name']) : "";
$tel = isset($_POST['tel']) ? $myts->makeTboxData4PreviewInForm($_POST['tel']) : "";
$organization = isset($_POST['organization']) ? $myts->makeTboxData4PreviewInForm($_POST['organization']) : "";
$country = isset($_POST['country']) ? $myts->makeTboxData4PreviewInForm($_POST['country']) : "";
$zipcode = isset($_POST['zipcode']) ? $myts->makeTboxData4PreviewInForm($_POST['zipcode']) : "";
$fax = isset($_POST['fax']) ? $myts->makeTboxData4PreviewInForm($_POST['fax']) : "";
$notice_mail = isset($_POST['notice_mail']) ? $myts->makeTboxData4PreviewInForm($_POST['notice_mail']) : "";
$private_item_limit = isset($_POST['private_item_limit']) ? $myts->makeTboxData4PreviewInForm($_POST['private_item_limit']) : "";

$email_tray = new XoopsFormElementTray(_US_EMAIL._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "<br />");
$email_text = new XoopsFormText("", "email", 25, 60, $email);
$email_option = new XoopsFormCheckBox("", "user_viewemail", $user_viewemail);
$email_option->addOption(1, _US_ALLOWVIEWEMAIL);
$email_tray->addElement($email_text);
$email_tray->addElement($email_option);

//$avatar_select = new XoopsFormSelect("", "user_avatar", $user_avatar);
//$avatar_array =& XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//$avatar_select->addOptionArray($avatar_array);
//$a_dirlist =& XoopsLists::getDirListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//$a_dir_labels = array();
//$a_count = 0;
//$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;start=".$a_count."','avatars',600,400);\">XOOPS</a>";
//$a_count = $a_count + count($avatar_array);
//$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//foreach ($a_dirlist as $a_dir) {
//	if ( $a_dir == "users" ) {
//		continue;
//	}
//	$avatars_array =& XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/".$a_dir."/", $a_dir."/");
//	$avatar_select->addOptionArray($avatars_array);
//	$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;subdir=".$a_dir."&amp;start=".$a_count."','avatars',600,400);\">".$a_dir."</a>";
//	$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//	$a_count = $a_count + count($avatars_array);
//}
//$avatar_select->setExtra("onchange='showImgSelected(\"avatar\", \"user_avatar\", \"images/avatar\", \"\", \"".XOOPS_URL."\")'");
//$avatar_label = new XoopsFormLabel("", "<img src='images/avatar/blank.gif' name='avatar' id='avatar' alt='' />");
//$avatar_tray = new XoopsFormElementTray(_US_AVATAR, "&nbsp;");
//$avatar_tray->addElement($avatar_select);
//$avatar_tray->addElement($avatar_label);
//foreach ($a_dir_labels as $a_dir_label) {
//	$avatar_tray->addElement($a_dir_label);
//}

include_once 'create_session.php';
xnp_load_init_create_session();
$val='';
$required = array();
foreach( array( 'realname', 'address', 'division', 'tel', 'company_name', 'country', 'zipcode', 'fax' ) as $k ){
	if( xnp_get_config_value( "account_${k}_optional", $val ) == RES_OK ){
		if( $val != 'on' ){
			$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
			$required[$k]['flag'] = true;
		}else{
			$required[$k]['mark'] = '';
			$required[$k]['flag'] = false;
		}
	}else{
		// require if not configured
		$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
		$required[$k]['flag'] = true;
	}
}

$reg_form = new XoopsThemeForm(_US_USERREG, "userinfo", "registeruser.php");
$uname_size = $xoopsConfigUser['maxuname'] < 25 ? $xoopsConfigUser['maxuname'] : 25;
$reg_form->addElement(new XoopsFormText(_US_NICKNAME._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "uname", $uname_size, $uname_size, $uname), true);
$reg_form->addElement(new XoopsFormText(_US_REALNAME.$required['realname']['mark'], "realname", 30, 60, $realname), $required['realname']['flag']);
$reg_form->addElement($email_tray);
$reg_form->addElement(new XoopsFormText(_US_WEBSITE, "url", 25, 255, $url));
$tzselected = ($timezone_offset != "") ? $timezone_offset : $xoopsConfig['default_TZ'];
$reg_form->addElement(new XoopsFormSelectTimezone(_US_TIMEZONE, "timezone_offset", $tzselected));
//$reg_form->addElement($avatar_tray);
$reg_form->addElement(new XoopsFormPassword(_US_PASSWORD._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "pass", 10, 32), true);
$reg_form->addElement(new XoopsFormPassword(_US_VERIFYPASS._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "vpass", 10, 32), true);
$reg_form->addElement(new XoopsFormRadioYN(_US_MAILOK, 'user_mailok', $user_mailok));

$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ADDRESS.$required['address']['mark'], 'address', 60, 255, $address), $required['address']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_DIVISION.$required['division']['mark'], 'division', 60, 255, $division), $required['division']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_TEL.$required['tel']['mark'], 'tel', 25, 32, $tel), $required['tel']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_FAX.$required['fax']['mark'], 'fax', 25, 32, $fax), $required['fax']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COMPANY_NAME.$required['company_name']['mark'], 'company_name', 60, 255, $company_name), $required['company_name']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COUNTRY.$required['country']['mark'], 'country', 25, 255, $country), $required['country']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ZIPCODE.$required['zipcode']['mark'], 'zipcode', 20, 32, $zipcode), $required['zipcode']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_NOTICE_MAIL, 'notice_mail', 5, 10, $notice_mail));

if ($xoopsConfigUser['reg_dispdsclmr'] != 0 && $xoopsConfigUser['reg_disclaimer'] != '') {
	$disc_tray = new XoopsFormElementTray(_US_DISCLAIMER, '<br />');
	$disc_text = new XoopsFormTextarea('', 'disclaimer', $xoopsConfigUser['reg_disclaimer'], 8);
	$disc_text->setExtra('readonly="readonly"');
	$disc_tray->addElement($disc_text);
	$agree_chk = new XoopsFormCheckBox('', 'agree_disc', 0);
	$agree_chk->addOption(1, _US_IAGREE);
	$disc_tray->addElement($agree_chk);
	$reg_form->addElement($disc_tray);
}

$reg_form->addElement(new XoopsFormHidden("op", "newuser"));
$reg_form->addElement(new XoopsFormButton("", "submit", _US_SUBMIT, "submit"));
$reg_form->setRequired($email_text);
?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/include/registerform.php <==
<?php
// $Id: registerform.php,v 1.11.2.1 2007/03/22 05:25:15 tani Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
//  This is based on XOOPS registerform.php                                  //
//  Modified like below                                                      //
//  - XooNIps user information is added(2005/5/18)                           //
//  ------------------------------------------------------------------------ //

include_once XOOPS_ROOT_PATH."/class/xoopslists.php";
include_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";

// initialize form vars
$uname = isset($_POST['uname']) ? $myts->makeTboxData4PreviewInForm($_POST['uname']) : "";
$realname = isset($_POST['realname']) ? $myts->makeTboxData4PreviewInForm($_POST['realname']) : "";
$email = isset($_POST['email']) ? $myts->makeTboxData4PreviewInForm($_POST['email']) : "";
$user_viewemail = isset($_POST['user_viewemail']) ? $_POST['user_viewemail'] : "";
$url = isset($_POST['url']) ? $myts->makeTboxData4PreviewInForm($_POST['url']) : "";
//$user_avatar = isset($_POST['user_avatar']) ? $_POST['user_avatar'] : "blank.gif";
// initialize form vars for platform user
$division = isset($_POST['division']) ? $myts->makeTboxData4PreviewInForm($_POST['division']) : "";
$company_name = isset($_POST['company_name']) ? $myts->makeTboxData4PreviewInForm($_POST['company_name']) : "";
$organization = isset($_POST['organization']) ? $myts->makeTboxData4PreviewInForm($_POST['organization']) : "";
$tel = isset($_POST['tel']) ? $myts->makeTboxData4PreviewInForm($_POST['tel']) : "";
$fax = isset($_POST['fax']) ? $myts->makeTboxData4PreviewInForm($_POST['fax']) : "";
$address = isset($_POST['address']) ? $myts->makeTboxData4PreviewInForm($_POST['address']) : "";
$country = isset($_POST['country']) ? $myts->makeTboxData4PreviewInForm($_POST['country']) : "";
$zipcode = isset($_POST['zipcode']) ? $myts->makeTboxData4PreviewInForm($_POST['zipcode']) : "";
$notice_mail = isset($_POST['notice_mail']) ? $myts->makeTboxData4PreviewInForm($_POST['notice_mail']) : "";
$timezone_offset = isset($_POST['timezone_offset']) ? $_POST['timezone_offset'] : "";
$private_item_limit = isset($_POST['private_item_limit']) ? $myts->makeTboxData4PreviewInForm($_POST['private_item_limit']) : "";

$email_tray = new XoopsFormElementTray(_US_EMAIL._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "<br />");
$email_text = new XoopsFormText("", "email", 25, 60, $email);
$email_option = new XoopsFormCheckBox("", "user_viewemail", $user_viewemail);
$email_option->addOption(1, _US_ALLOWVIEWEMAIL);
$email_tray->addElement($email_text);
$email_tray->addElement($email_option);

//$avatar_select = new XoopsFormSelect("", "user_avatar", $user_avatar);
//$avatar_array =& XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//$avatar_select->addOptionArray($avatar_array);
//$a_dirlist =& XoopsLists::getDirListAsArray(XOOPS_ROOT_PATH."/images/avatar/");
//$a_dir_labels = array();
//$a_count = 0;
//$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;start=".$a_count."','avatars',600,400);\">XOOPS</a>";
//$a_count = $a_count + count($avatar_array);
//$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//foreach ($a_dirlist as $a_dir) {
//	if ( $a_dir == "users" ) {
//		continue;
//	}
//	$avatars_array =& XoopsLists::getImgListAsArray(XOOPS_ROOT_PATH."/images/avatar/".$a_dir."/", $a_dir."/");
//	$avatar_select->addOptionArray($avatars_array);
//	$a_dir_link = "<a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars&amp;subdir=".$a_dir."&amp;start=".$a_count."','avatars',600,400);\">".$a_dir."</a>";
//	$a_dir_labels[] = new XoopsFormLabel("", $a_dir_link);
//	$a_count = $a_count + count($avatars_array);
//}
//$avatar_select->setExtra("onchange='showImgSelected(\"avatar\", \"user_avatar\", \"images/avatar\", \"\", \"".XOOPS_URL."\")'");
//$avatar_label = new XoopsFormLabel("", "<img src='images/avatar/blank.gif' name='avatar' id='avatar' alt='' />");
//$avatar_tray = new XoopsFormElementTray(_US_AVATAR, "&nbsp;");
//$avatar_tray->addElement($avatar_select);
//$avatar_tray->addElement($avatar_label);
//foreach ($a_dir_labels as $a_dir_label) {
//	$avatar_tray->addElement($a_dir_label);
//}

include_once 'create_session.php';
xnp_load_init_create_session();
$val='';
$required = array();
foreach( array( 'realname', 'address', 'division', 'tel', 'company_name', 'country', 'zipcode', 'fax' ) as $k ){
	if( xnp_get_config_value( "account_${k}_optional", $val ) == RES_OK ){
		if( $val != 'on' ){
			$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
			$required[$k]['flag'] = true;
		}else{
			$required[$k]['mark'] = '';
			$required[$k]['flag'] = false;
		}
	}else{
		// require if not configured
		$required[$k]['mark'] = _MD_XOONIPS_ACCOUNT_REQUIRED_MARK;
		$required[$k]['flag'] = true;
	}
}

$reg_form = new XoopsThemeForm(_US_USERREG, "userinfo", "registeruser.php");
$uname_size = $xoopsConfigUser['maxuname'] < 25 ? $xoopsConfigUser['maxuname'] : 25;
$reg_form->addElement(new XoopsFormText(_US_NICKNAME._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "uname", $uname_size, $uname_size, $uname), true);
$reg_form->addElement(new XoopsFormText(_US_REALNAME.$required['realname']['mark'], "realname", 30, 60, $realname), $required['realname']['flag']);
$reg_form->addElement($email_tray);
$reg_form->addElement(new XoopsFormText(_US_WEBSITE, "url", 25, 255, $url));
//$reg_form->addElement($avatar_tray);
$reg_form->addElement(new XoopsFormPassword(_US_PASSWORD._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "pass", 10, 32), true);
$reg_form->addElement(new XoopsFormPassword(_US_VERIFYPASS._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, "vpass", 10, 32), true);

$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_DIVISION.$required['division']['mark'], 'division', 60, 255, $division), $required['division']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COMPANY_NAME.$required['company_name']['mark'], 'company_name', 60, 255, $company_name), $required['company_name']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_TEL.$required['tel']['mark'], 'tel', 25, 32, $tel), $required['tel']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_FAX.$required['fax']['mark'], 'fax', 25, 32, $fax), $required['fax']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ADDRESS.$required['address']['mark'], 'address', 60, 255, $address), $required['address']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COUNTRY.$required['country']['mark'], 'country', 25, 255, $country), $required['country']['flag']);
$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ZIPCODE.$required['zipcode']['mark'], 'zipcode', 20, 32, $zipcode), $required['zipcode']['flag']);

$tzselected = ($timezone_offset != "") ? $timezone_offset : $xoopsConfig['default_TZ'];
$reg_form->addElement(new XoopsFormSelectTimezone(_US_TIMEZONE, "timezone_offset", $tzselected));

$reg_form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_NOTICE_MAIL, 'notice_mail', 5, 10, $notice_mail));
$reg_form->addElement(new XoopsFormRadioYN(_US_MAILOK, 'user_mailok', $user_mailok));

if ($xoopsConfigUser['reg_dispdsclmr'] != 0 && $xoopsConfigUser['reg_disclaimer'] != '') {
	$disc_tray = new XoopsFormElementTray(_US_DISCLAIMER, '<br />');
	$disc_text = new XoopsFormTextarea('', 'disclaimer', $xoopsConfigUser['reg_disclaimer'], 8);
	$disc_text->setExtra('readonly="readonly"');
	$disc_tray->addElement($disc_text);
	$agree_chk = new XoopsFormCheckBox('', 'agree_disc', 0);
	$agree_chk->addOption(1, _US_IAGREE);
	$disc_tray->addElement($agree_chk);
	$reg_form->addElement($disc_tray);
}

$reg_form->addElement(new XoopsFormHidden("op", "newuser"));
$reg_form->addElement(new XoopsFormButton("", "submit", _US_SUBMIT, "submit"));
$reg_form->setRequired($email_text);
?>
